PodGen — PodGen Documentation

# PodGen

Don’t you wish there was a clean and simple library which could help you generate podcast RSS feeds with your Python code? Well, today’s your lucky day!

    >>> from podgen import Podcast, Episode, Media
    >>> # Create the Podcast
    >>> p = Podcast(
           name="The Library Tuesday Talk",
           description="My friends and I discuss Python"
                       " libraries each Tuesday!",
           website="http://example.org/librarytuesdaytalk"
        )
    >>> # Add some episodes
    >>> p.episodes += [
           Episode(title="Worry about timezones no more",
                   media=Media("http://example.org/ep1.mp3", 11932295),
                   summary="Using pytz, you can make your code timezone-aware "
                           "with very little hassle."),
           Episode(title="Heard about clint?",
                   media=Media("http://example.org/ep2.mp3", 15363464),
                   summary="The man behind Requests made something useful "
                           "for us command-line nerds."
        ]
    >>> # Generate the RSS feed
    >>> rss = str(p)

You don’t need to read the RSS specification, write XML by hand or wrap your head around ambiguous, undocumented APIs. PodGen incorporates the industry’s best practices and lets you focus on collecting the necessary metadata and publishing the podcast.

PodGen is compatible with Python 2.7 and 3.3+.

## User Guide

- Introduction
  - Philosophy
  - Scope
  - License
- Installation
- Why the fork?
  - Inspiration
  - Alignment with the philosophies
  - Summary of changes
- Creating the podcast
  - Creating a new instance
  - Mandatory attributes
  - Image
  - Optional attributes
    - Commonly used
    - Less commonly used
  - Shortcut for filling in data
- Adding episodes
  - Filling with data
    - Enclosing media
    - Identifying the episode
    - Episode’s publication date
    - The Link
    - The Authors
    - Less used attributes
  - Shortcut for filling in data
- Generating the RSS
- Full example
- Advanced Topics
  - Using PubSubHubbub
    - Step 1: Set feed_url
    - Step 2: Decide on a hub
    - Step 3: Set pubsubhubbub
    - Step 4: Set HTTP Link Header
    - Step 5: Publish the changes
    - Step 6: Notify the hub of new episodes
  - Adding new tags
    - Quick How-to
    - Example: Adding a ttl element
- Contributing
  - Setting up
  - Testing
  - Values
  - The Workflow
- API Documentation